#
# spec file for package python-networking-cisco
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define component networking-cisco
%define groupname neutron

%define version_unconverted 6.1.1.dev65

Name:           python-networking-cisco
Version:        6.1.1~dev65
Release:        4.1
Summary:        Cisco for OpenStack Networking (Neutron)
License:        Apache-2.0
Group:          System/Management
Url:            https://pypi.python.org/pypi/networking-cisco
Source:         http://tarballs.openstack.org/networking-cisco/networking-cisco-master.tar.gz
Source1:        neutron-cisco-cfg-agent.service
BuildRequires:  fdupes
BuildRequires:  openstack-suse-macros
BuildRequires:  python-pbr
BuildRequires:  systemd-rpm-macros
Requires:       openstack-neutron
Requires:       python >= 2.7
Requires:       python-Babel >= 1.3
Requires:       python-lxml >= 3.3.3
Requires:       python-ncclient >= 0.4.6
Requires:       python-neutron-lib >= 0.1.0
Requires:       python-neutronclient
Requires:       python-oslo.concurrency >= 3.5.0
Requires:       python-oslo.config >= 3.7.0
Requires:       python-oslo.db >= 4.1.0
Requires:       python-oslo.i18n >= 2.1.0
Requires:       python-oslo.log >= 1.14.0
Requires:       python-oslo.messaging >= 4.0.0
Requires:       python-oslo.serialization >= 1.10.0
Requires:       python-oslo.service >= 1.0.0
Requires:       python-oslo.utils >= 3.5.0
Requires:       python-pika >= 0.10.0
Requires:       python-ucsmsdk >= 0.9.3.1
%{?systemd_requires}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
Networking Cisco contains the Cisco vendor code for OpenStack Neutron.


%package test
Summary:        Cisco for OpenStack Networking (Neutron) - Testsuite
Group:          System/Management
Requires:       %{name} = %{version}
Requires:       python-WebTest >= 2.0
Requires:       python-mock >= 1.2
Requires:       python-os-testr >= 0.4.1
Requires:       python-oslotest >= 1.10.0
Requires:       python-python-subunit >= 0.0.18
Requires:       python-requests-mock >= 0.7.0
Requires:       python-testresources >= 0.2.4
Requires:       python-testscenarios >= 0.4
Requires:       python-testtools >= 1.4.0

%description test
The testsuite for the Cisco for OpenStack Networking.

%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep

%build
python setup.py build

%install
python setup.py install --root %{buildroot} --prefix %{_prefix}

# config files
mv %{buildroot}/usr/etc %{buildroot}/%{_sysconfdir}
mkdir -p %{buildroot}%{_datarootdir}/cpnr/rootwrap
mkdir -p %{buildroot}%{_sysconfdir}/neutron/plugins/cisco
mkdir -p %{buildroot}%{_sysconfdir}/neutron/plugins/ml2
mv %{buildroot}/etc/init/cpnr*.conf %{buildroot}%{_sysconfdir}/cpnr/
mv %{buildroot}/etc/neutron/cisco_* %{buildroot}%{_sysconfdir}/neutron/plugins/cisco/
mv %{buildroot}/usr/usr/share/cpnr/rootwrap/*.filters %{buildroot}%{_datarootdir}/cpnr/rootwrap/

### init scripts (systemd)
#mkdir -p %{buildroot}%{_sbindir}
%__install -D -m 444 %{buildroot}/etc/saf/init/fabric-enabler-server.service %{buildroot}/%{_unitdir}/fabric-enabler-server.service
%__install -D -m 444 %{buildroot}/etc/saf/init/fabric-enabler-agent.service %{buildroot}/%{_unitdir}/fabric-enabler-agent.service
%__install -D -m 444 %{buildroot}/etc/systemd/system/cpnr-dhcp-relay.service %{buildroot}/%{_unitdir}/cpnr-dhcp-relay.service
%__install -D -m 444 %{buildroot}/etc/systemd/system/cpnr-dns-relay.service %{buildroot}/%{_unitdir}/cpnr-dns-relay.service
%__install -p -D -m 444 %{SOURCE1} %{buildroot}/%{_unitdir}/neutron-cisco-cfg-agent.service

# cleanup
rm -rf %{buildroot}/etc/saf/init/
rm -rf %{buildroot}/etc/systemd/

%fdupes %{buildroot}%{python_sitelib}/

%files
%defattr(-,root,root,-)
%doc LICENSE
%{python_sitelib}/networking_cisco/
%{python_sitelib}/networking_cisco*.egg-info
# Part of test subpackage
%{python_sitelib}/networking_cisco_tempest_plugin/
%exclude %{python_sitelib}/networking_cisco/tests
# config
%dir %{_sysconfdir}/neutron
%dir %{_sysconfdir}/neutron/plugins
%dir %{_sysconfdir}/neutron/plugins/cisco
%dir %{_sysconfdir}/neutron/plugins/ml2
%dir %{_sysconfdir}/saf
%dir %{_sysconfdir}/cpnr
%dir %{_datarootdir}/cpnr
%dir %{_datarootdir}/cpnr/rootwrap
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/cpnr/cisco_pnr.ini
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/cpnr/cpnr-dhcp-relay.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/cpnr/cpnr-dns-relay.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/cpnr/rootwrap.conf
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/neutron/plugins/cisco/cisco_cfg_agent.ini
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/neutron/plugins/cisco/cisco_device_manager_plugin.ini
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/neutron/plugins/cisco/cisco_router_plugin.ini
%config(noreplace) %attr(0640, root, %{groupname}) %{_sysconfdir}/saf/enabler_conf.ini
%config(noreplace) %attr(0640, root, %{groupname}) %{_datarootdir}/cpnr/rootwrap/cpnr.filters
# bin
%{_bindir}/cpnr-dhcp-relay
%{_bindir}/cpnr-dhcp-relay-agent
%{_bindir}/cpnr-dns-relay
%{_bindir}/cpnr-dns-relay-agent
%{_bindir}/cpnr-rootwrap
%{_bindir}/fabric-enabler-agent
%{_bindir}/fabric-enabler-cli
%{_bindir}/fabric-enabler-server
%{_bindir}/neutron-cisco-cfg-agent
# systemd
%{_unitdir}/cpnr-dhcp-relay.service
%{_unitdir}/cpnr-dns-relay.service
%{_unitdir}/fabric-enabler-server.service
%{_unitdir}/fabric-enabler-agent.service
%{_unitdir}/neutron-cisco-cfg-agent.service

%files test
%defattr(-,root,root)
%doc LICENSE
%{python_sitelib}/networking_cisco/tests

%pre
%service_add_pre cpnr-dhcp-relay-agent
%service_add_pre cpnr-dns-relay-agent
%service_add_pre fabric-enabler-agent.service
%service_add_pre fabric-enabler-server.service
%service_add_pre neutron-cisco-cfg-agent.service

%post
%service_add_post cpnr-dhcp-relay-agent
%service_add_post cpnr-dns-relay-agent
%service_add_post fabric-enabler-server.service
%service_add_post fabric-enabler-agent.service
%service_add_post neutron-cisco-cfg-agent.service

%preun
%service_del_preun cpnr-dhcp-relay-agent
%service_del_preun cpnr-dns-relay-agent
%service_del_preun fabric-enabler-server.service
%service_del_preun fabric-enabler-agent.service
%service_del_preun neutron-cisco-cfg-agent.service

%postun
%service_del_postun cpnr-dhcp-relay-agent
%service_del_postun cpnr-dns-relay-agent
%service_del_postun fabric-enabler-server.service
%service_del_postun fabric-enabler-agent.service
%service_del_postun neutron-cisco-cfg-agent.service

%changelog
* Mon Dec 10 2018 sma@suse.com
- Corrected the python-UcsSdk >= 0.9.3.1 requirement. The name of
  the package is actually "python-ucsmsdk".
* Wed Dec  5 2018 sma@suse.com
- Update to version 6.1.1.dev65
  * Removed files that are no longer found in the tarball.
  * Updated Python package requirements.
* Mon Aug 13 2018 comurphy@suse.com
- Drop tempest-lib dependency
* Tue Dec 12 2017 gayane.osipyan@suse.com
- Add networking_cisco_tempest_plugin
* Tue Dec 12 2017 gosipyan@suse.com 
- Update to version networking-cisco-5.3.1.dev2:
  * Nexus RESTAPI Improvements
  * Pin doc tox build to stable/pike
  5.3.0
  * Fix remaining comments and indentation for the ASR1k docs
  * UCSM mech driver Install, Admin and Configuration docs
  * ASR1k documentation
  * Cleanup of some Nexus and a CPNR doc files
  * Document plugin/drivers Deprecation
  * Alter a few Nexus message severity
  * Fix horrible module level skipTest in test\_migrations
  * Remove the onwards part from the support versions
  * Stop using is\_agent\_down
  * Fixes incorrect retry mechanism in asr1k router type driver unit tests
  * Zuul: add file extension to playbook path
  * Fix bug in \_get\_config\_generator\_config\_definition
  * Run pep8 using latest hacking rules and fix remaining issues
  * Add Error Handling to troubleshoot guide
  * Stop translating logging for SAF
  * Expand config help text with ml2\_conf\_cisco.ini
  * Update networking-cisco for Zuul v3
  * Nexus VXLAN Type Driver Configuration Reference
  * Make cfg agent fetch hosting devices to manage during startup
  * Miscellaneous doc cleanup
  * Optimise the tox\_install script
  * Update tox-install for zuulv3 world
  * Stop translating logging for cisco.extensions
  * Stop translating logging for ucsm
* Sat Aug 26 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.2.1.dev6:
  * Release note for nexus trunk support
  * Release note for Provider Network Limited Operations
  * Remove unused Nexus configuration
  5.2.0
  * Remove references to import attributes.py
* Fri Aug 18 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev18:
  * Fix neutron server crash introduced by trunk code
  * Provide ability to turn on DEBUG logging in unit tests
* Thu Aug 17 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev16:
  * Nexus provider network support
  * ASR1K plugin: conditionally append v3 to authurl
* Wed Aug 16 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev13:
  * Refactor/Refine the core automated vPC code
  * Update README now that new docs are published
* Tue Aug 15 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev10:
  * Nexus ml2 plugin causing neutron crash at \_load\_nexus\_cfg\_driver
* Fri Aug 11 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev9:
  * Make restapi driver more independent
* Sat Aug  5 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev8:
  * Allow user provided port-channel commands
* Fri Aug  4 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev6:
  * Redesign the look and feel of the networking-cisco docs
* Wed Aug  2 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.1.1.dev5:
  * Stop using OpenStack docs theme
  5.1.0
  * Fixing devstack issues for mitaka
  * Do not create HA redundancy router for HA redundancy router
  * Makes maximum chunk size for router sync configurable
* Thu Jul 27 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev44:
  * Update the networking-cisco README with some info
* Sat Jul 22 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev43:
  * Set RESTAPI Driver as default for ML2 Nexus
  * UCSM ML2 driver: Fix issue in parsing of single UCSM config
* Fri Jul 21 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev41:
  * Re-enable non-trunk baremetal test cases
* Wed Jul 19 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev40:
  * Handle multiple controllers in vpcid allocate db
  * Nexus MD: Neutron trunk support
  * Disables return code check in REST API update calls from some unit tests
* Tue Jul 11 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev36:
  * Switch mitaka tests to mitaka-eol tag instead of branch
* Sat Jul  1 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev34:
  * Fixes incorrect format strings in log statements
* Thu Jun 29 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev32:
  * Nexus Baremetal Automated Port Channel Creation
  * Handle missing ha:details attribute in router type driver unit tests
  * Takes hosting information into account when determining updated routers
* Tue Jun 27 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev26:
  * Retry Config agent registration with the neutron server
  * Allow router actions to create/update the port resource
  * Rename Column TenantId to ProjectID in DB
* Sat Jun 17 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev21:
  * Workaround failing UT for asr1k router type driver
* Fri Jun 16 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev19:
  * Reject REST API operations on L3 resources owned by ASR1k L3 router plugin
  * Fixing devstack issues
* Thu Jun 15 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev15:
  * Change name of HA redundancy router automatically
* Sat Jun  3 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev13:
  * ML2 Nexus Add Host/interface mapping table
  * Stabilize Ocata Jenkins runs
* Wed May 24 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev11:
  * Nexus: Add additional router device owner types to support
  * Resolve latest set of Jenkins errors
* Wed May  3 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev9:
  * Portbinding extension moved to neutron\_lib
  * Use function is\_valid\_mac from oslo.utils
  * Accept ucsm\_host\_list as part of Multi-UCSM config
  * Use exceptions and constants from neutron\_lib
  * CPNR plugin is changed to use cisco\_pnr.ini for configuration
  * Fix test\_migrations
  * Remove neutron dependency from test\_cisco\_mech.py
  * Moved deprecated constants from neutron.common to neutron\_lib
  * Fixed deprecation warnings with 'INTERFACE\_KEY'
  * Moved deprecated ATTR\_NOT\_SPECIFIED to neutron\_lib
  * Moved more deprecated exceptions from neutron.common to neutron\_lib
  * Moved deprecated exceptions from neutron.common to neutron\_lib
  * Fixed deprecation warnings with 'DEVICE\_OWNER'
  * Moved converter functions to neutron\_lib.api
  * Use is\_valid\_port from oslo.utils
  * Use method is\_valid\_ipv\* from oslo.utils
  * Add manila as valid device\_owner
  * Use is\_valid\_ipv4 from oslo.utils
  * Do not update host\_id on ports for routers in hosting devices
  * Catch DB exceptions defined in oslo\_db instead of MySQL
  * Enabling/Disabling the neutron router should correspondingly enable/disable the external and/or internal network sub interfaces on the ASR. The fix also updates the admin\_state\_up of the backup router when the admin\_state\_up of the tenant router is changed
  * Changes to admin\_state\_up is not reflected on backup routers
  * Added flexibility to add openstack client auth credentials to our cfg file 1. Change the authentication syntax to be more aligned with auth\_section    in preparation of using auth plugin in the future. i.e., instead of using    admin\_user\_name, use username... 2. Added more flexibility that if those authentication credential fields    are not present in openstack configure file, we can add them in our    enabler\_conf.ini.  To do that, we here eliminated the dependency on nova    config file. 3. If a field is present in both openstack and our enabler\_conf.ini, our    config file will overwrite 4. In the future, we will totally eliminate the reading of openstack config    file. But for now, we don't want much code changes, so still keep the current    way of reading neutron and keystone config files
  * Don't unschedule routers with auto\_schedule=False from dead hosting devices
  * Attribute nve\_src\_intf causing bad behavior
  * Fix so external\_net\_interface defines in .ini file are used
  * Make cisco\_router script patch neutron\_legacy script
  * use curl instead of wget in tools/tox\_install.sh
  * Retries cause Nexus bind\_port failure
  * Fixes the UT failure in l3\_router\_appliance\_plugin Adds a few pep8 fixes
* Fri Apr  7 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev8:
  * Use function is_valid_mac from oslo.utils
* Wed Apr  5 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev7:
  * UCSM plugin: Auto detection of compute hosts
* Wed Mar 22 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev6:
  * UCSM Driver retry Port Profile deletes
* Tue Mar 21 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev5:
  * Use correct netmask for router interfaces in ASR1k
* Wed Mar 15 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev4:
  * Accept ucsm_host_list as part of Multi-UCSM config
* Tue Mar 14 2017 cloud-devel@suse.de
- Update to version networking-cisco-5.0.1.dev2:
  * Adds support for multiple subnets per external network
  5.0.0
* Wed Mar  8 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev28:
  * Update imports for Agent, Router and RouterPort in networking-cisco
  * Implement Rest API in ML2 Nexus Driver
* Fri Mar  3 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev25:
  * ML2 Nexus VXLAN TunnelTypeDriver needs upgrade
  * ML2 Nexus driver fails on SessionCloseError
* Sat Feb 25 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev21:
  * Native LBaaS support
* Fri Feb 17 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev20:
  * Implementation of Topology Discovery in SAF using Nexus switches
* Thu Feb 16 2017 nicolas.bock@suse.com
- Removed the two *apic* services from the ACI plugin
- Update to version networking-cisco-4.0.1.dev18:
  * Remove ACI plugin
  * remove restart keystone
  * use auth session for keystoneclient, novaclient and neutronclient
  * fix rpc, wait is for stop to wait to drain the message, it is not for
    waiting message to arrive
  * Totally remove the dependency on keystone.conf and neutron.conf
  * minor bug fix
* Sat Feb 11 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev14:
  * Agent Related fixes and improve UT Coverage
* Fri Feb 10 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev12:
  * Ensure that networking-cisco migrations work for Ocata
  * Bring networking-cisco up to date with neutron ocata
* Wed Jan  4 2017 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev10:
  * Update networking-cisco README
* Fri Dec 23 2016 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev8:
  * Fixes timeout exception raised by config agent during a router sync
* Wed Dec  7 2016 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev7:
  * Adds router support for more than one external network
  * Add support for in-tree release notes
* Tue Dec  6 2016 cloud-devel@suse.de
- Update to version networking-cisco-4.0.1.dev4:
  * Use exceptions and constants from neutron_lib
* Fri Nov 25 2016 nicolas.bock@suse.com
- Update to version networking-cisco-4.0.1.dev3:
  * CPNR plugin is changed to use cisco_pnr.ini for configuration
* Mon Oct 24 2016 nicolas.bock@suse.com
- Updated spec file with upstream changes
* Mon Oct 24 2016 nicolas.bock@suse.com
- Update to version networking-cisco-4.0.1.dev2:
  * Fix a typo in rootwrap.conf,cisco-apic.filters and cpnr.filters
  4.0.0
  * Retry fip and router port status updates that fail due to DB errors
  * Changing coverage target names
  * Clean up backward compatibility flags
  * Make sure test imports are separate from runtime code
  * Handle deleted router gracefully when processing router backlog
  * Support for https with Nexus fabric enabler
  * Add missing %%s in print message
  * Added GBP workflow for floating IPs
  * Remove white space between print and ()
  * Devstack support for Native FW and Phy ASA driver in SAF
  * Add plugging driver for ACI integration
  * Revert "Fix router creation"
  * SIGTERM handler added to CPNR Relay plugin
  * Added floating IP precommit call
  * Generalize route cleanup
  * Fixes agent scheduler related UT failures
  * Fix router creation
  * Fix Nexus Copyright messages
  * Fix test_migrations
  * Restore coverage test operation
  * TrivialFix: Remove logging import unused
  * Fixes for UT failures in master
  * Remove neutron dependency from test_cisco_mech.py
  * Resolve comments in debug for OSP issue 1607847
  * Fix recent ASR1K pep8 issue
* Wed Aug 24 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev17:
  * Add master tox env and allow all ostestr arguments
  * Generalize routing service helper
* Tue Aug 23 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev14:
  * Nexus threads prematurely terminating sessions
  * Add routertype driver callouts to L3 Plugin
* Sat Aug 20 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev10:
  * UCSM plugin: Support for SP sub-orgs and hostnames with extensions
* Fri Aug 19 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev9:
  * Pin networking-cisco upper-constraits to stable/mitaka
* Sat Aug  6 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev8:
  * Resolve recent batch of unit tests failures
* Sun Jul 31 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev7:
  * Set default DNS attribute value
* Fri Jul 15 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev6:
  * UT Fix: Skip DVR related test
* Wed Jul 13 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev5:
  * Add manila as valid device_owner
* Sun Jul  3 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev4:
  * Correctly determine router for floatingip
* Tue Jun 28 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev3:
  * Handle deleted port gracefully when populating hosting info
* Fri Jun 24 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.2.1.dev1:
  * Fix wrong usage of novaclient
  3.2.0
* Tue Jun  7 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev19:
  * Use --subproject instead of deprecated --service option
* Wed Jun  1 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev17:
  * Fix issues seen in cisco router install scripts with Keystone
* Fri May 27 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev16:
  * UCSM : Local Multi-VLAN trunk network and QoS Policy support
  * Changes to acl naming
* Wed May 25 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev14:
  * Address cfg-sync removal of valid ASR config
  * Fix ASR clean-up for empty neutron-db
* Tue May 24 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev11:
  * Address configuration clash in multi-region setup
* Thu May 19 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev9:
  * Ensure global router cleanup An additional method is introduced as part of the backlog processing loop that scans global routers. If there are global routers associated to a hosting device without any associated tenant routers or redundancy routers having their gateway set on that hosting device, then it will delete those global routers. The logical global router is also conditionally removed (when all global routers are deleted)
  * Corrects router misprogramming after device reboot
* Fri May 13 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev5:
  * Address double-resync of hardware hosting-devices
* Thu May 12 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev3:
  * Fix DHCP option 121 parsing
* Mon May  9 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.1.dev1:
  * Switch to using hacking checks from neutron-lib
* Thu Apr 21 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.1.0:
  3.1.0
  * VNIC Template support in ML2 UCS Manager plugin
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.0.1.dev6:
  * Changes logging of transient issue from error to debug type
  * Do not update host_id on ports for routers in hosting devices
  * Catch DB exceptions defined in oslo_db instead of MySQL
  * New neutron plugin code to support CPNR product
  * Added flexibility to add openstack client auth credentials to our cfg file 1. Change the authentication syntax to be more aligned with auth_section    in preparation of using auth plugin in the future. i.e., instead of using    admin_user_name, use username... 2. Added more flexibility that if those authentication credential fields    are not present in openstack configure file, we can add them in our    enabler_conf.ini.  To do that, we here eliminated the dependency on nova    config file. 3. If a field is present in both openstack and our enabler_conf.ini, our    config file will overwrite 4. In the future, we will totally eliminate the reading of openstack config    file. But for now, we don't want much code changes, so still keep the current    way of reading neutron and keystone config files
  * Extends neutronclient with commands for device and router management
  * Arista ML2 Mechanism driver
  * Copy the RHEL6 eventlet workaround from Oslo
  * fix bug lp:1025526,update iniparser.py to accept  empty value
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version networking-cisco-3.0.1.dev1:
  * Retry if HA group info is not found for HA enabled router
  3.0.0
* Sat Apr  9 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev111:
  * Prevent duplicate ACL configuration A check is made to ensure that we are not configuring ACL for a second time as that will result in an error
  * Enabling/Disabling the neutron router should correspondingly enable/disable the external and/or internal network sub interfaces on the ASR. The fix also updates the admin_state_up of the backup router when the admin_state_up of the tenant router is changed
* Fri Apr  8 2016 tbechtold@suse.com
- Update to version networking-cisco-2.0.1.dev109:
  * Implement policy profile update CLI for n1kv
  * Correct the name and path of plugin files
  * Add oslo dependencies to requirements.txt
- Install cpnr-dhcp-relay and cpnr-dns-relay in /usr/bin
  (renamed again upstream)
- Adjust Requires
* Thu Apr  7 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev103:
  * Account for some transients in the db so we force agent to retry
  * This is the install guide for PNR plugin
* Wed Apr  6 2016 tbechtold@suse.com
- Update to version networking-cisco-2.0.1.dev100:
  * Rename neutron-dhcp-relay and neutron-dns-relay
  * UCSM MD scale, cache UCSM connection handle for full public method
- Adjust Requires
- Install renamed neutron-cisco-dhcp-relay and neutron-cisco-dns-relay
  into /usr/bin/
* Tue Apr  5 2016 tbechtold@suse.com
- Update to version networking-cisco-2.0.1.dev96:
  * New neutron plugin code to support CPNR product
  * Added flexibility to add openstack client auth credentials to our
    cfg file
  * fix typo "Openstck"
- Install /usr/bin/neutron-dhcp-relay and /usr/bin/neutron-dns-relay
* Fri Apr  1 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev90:
  * Add apicapi to requirements.txt
  * Service Profile Template Support in Cisco UCSM ML2 driver
* Thu Mar 31 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev86:
  * Changes to admin_state_up is not reflected on backup routers
  * UCSM MD scale improvement, selectively process port updates
* Tue Mar 29 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev83:
  * Replace ciscoconfparser with HTParser
* Fri Mar 25 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev82:
  * Provide method removed from neutron to prevent breakage
  * Pin networking-cisco to Neutron stable/mikata
* Wed Mar 23 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev79:
  * Handle multiple concurrent scheduling attempts for the same router
* Tue Mar 22 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev77:
  * Making cfg-agent keepalive more proactive and configurable
  * Update config agent monitoring timers
  * Properly clean up after failed router gateway updates
  * Openstack native DHCP support for SAF enabler
  * Monitor status of config agents more comprehensively
* Fri Mar 18 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev70:
  * Adds l3 plugin & cfg agent RPC for removed routers
  * This fix assigns different HSRP priority to the external and internal sub-interface on the active and the backup routers
  * Fix issues with parsing of some new single UCSM config
  * Improve device config error logging
  * Use constraints for networking-cisco
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev61:
  * Fix latest unit test failures for Nexus py34
* Wed Mar 16 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev60:
  * Don't unschedule routers with auto_schedule=False from dead hosting devices
  * Ensure that router config removal happens only on active devices
  * Fix for defect: Fail to clear default route
* Tue Mar 15 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev55:
  * Adds RPC to allow config agent to update hosting device status
  * Delete router routes before router delete in unittest teardown
* Fri Mar 11 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev53:
  * Use public method execute() for client extension
  * Use HA VIP address for NAT pools
  * Adds support for extension standard-attr-description
* Fri Mar  4 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev49:
  * Add oslo db retry decorator to the RPC handlers
  * Fix so external_net_interface defines in .ini file are used
* Thu Mar  3 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev45:
  * Attribute nve_src_intf causing bad behavior
  * HSRP Default Priority change
  * Make cisco_router script patch neutron_legacy script
  * Added proxy settings to tox.ini
  * Coverage with comparison against baseline
  * Support of static uplink port detection
  * use curl instead of wget in tools/tox_install.sh
* Fri Feb 26 2016 cloud-devel@suse.de
- Update to version networking-cisco-2.0.1.dev32:
  * Remove prohibition of bash scripts
  * Make vNIC names explicit in UCSM plugin
  * Handle new baremetal format of port-id field
  * Fixes recent UCSM CI breakage
  * Retries cause Nexus bind_port failure
  * LOG.warn -> LOG.warning
  * Change import exclusions in tox.ini and update imports
  * Fixes the UT failure in a DVR test
  * Fixes the UT failure in l3_router_appliance_plugin Adds a few pep8 fixes
  * Nexus baremetal/Ironic code clean-up
  * Fix misspellings
  * Remove openstack-common.conf
* Thu Feb  4 2016 tbechtold@suse.com
- Initial packaging (version 2.0.1~a0~dev4)
